/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvControlCast.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvMath.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_3TiZzHM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FD8GzGHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Larw0SDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1si5qZuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2yF6KU3v_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VB2N1fgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZrZ4YvCR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_m0qyHBJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gpcflSWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sKaBNSSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ocDCcOpx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Va9BaCcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WAh8i4qQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U787T57n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MyjKXwBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WsbCKsx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RGODLzfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uK4ciWiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ByZfS3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IYYSFFls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IL1NHUql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W1AJi1ID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3pnXB16m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0HjWUmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XIZU4S53_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XWgwE5s1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kl6trUHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0FrrwFKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VdpSkHSL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0rVvUMgQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NIzLCxpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KiN4EdHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dGdtYXTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hVjaE1z2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C4hTBQmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fo9cdJs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dBzl12x5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4XAe1Q2u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NyYTnXvb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eFF19Ti3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tNArEbZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K8ABnSsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fDjmgB3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_x62ZKVHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EDVEVILI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U9BmChhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VEVqIo1w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z8JYCIih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I8IUJGNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IJ81zupT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JDFLfUJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qSvTPXZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pmD1cni8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ndz1yVB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xibhVU8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E9p83bLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_836vqsP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n2KIRWUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Zw77Zx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tjttSMWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XPKLKzHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VkhoHB7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MGDROdCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xqy8qL0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cLviec0V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a9HahfVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QPxVymb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EVkK5DVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KH29FlrZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qqOBcCc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eXKOqvHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zXFN1Dov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EpD5aIGZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_drSL5ig4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vguvejq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vdwW3gAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m0vXOg8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tFrdn9DP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MJQeHJWn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_z7N1AGaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0moLF1M2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tag7pDKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0Cf06qf1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Bwtn4W9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VAWwjABe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KSYT4KVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v7BQadcb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kuJImnuZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pGFfO1lx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jgS4mhbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1ZPxNCbo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cpZ0MmAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iYdc6OUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IZcaZcyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PZEt0PUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtxSTJGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BLdckITu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mP8ifXLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VD6YWCL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k9cpfCUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iHUN1hdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_W5Nn1KjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mAU5NmAr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NeInS1gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rkhAWNi9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_upm6VWIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k3Rn2Afg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2SbkFVAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gXL2CbHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XPRsmybZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eUyOKBfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DigWbyy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_haaChyZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mf7XtWCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i0yAd5le_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrH1SnFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nl3jFsHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8BAZq5da_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQXlVE6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8zm3rf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ycznjj1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lEwhKV8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_auPJDSQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u3apqJEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RZdSo10Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JrYZca8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VT1DJBBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C1zPjjCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hCEunPMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zqjccqmK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_psT32wXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_19wJN13f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dyzWY5vJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7jH9SnPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_spbvtqb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pfmJ8rqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bao0O3ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyPGxDG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4MrrfGDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_13dOS1kD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TKlXixmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bis8MbW6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9WZpSM7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u6VRT7Ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GrqE8Dvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_36ReGYsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FjmmXSk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BOz42yCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n45y0UM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_87cwiaC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_su7fY9Dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FVWq7dBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JQ1CdOgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hP062pCH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6HQkiYDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jcw7wmm0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q4ZvOoNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_22HNphaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AWzflOlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MHcUmW88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kc76uUj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8IL4mkdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_630kkyGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fRjx2BHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_03yiA0eC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mh8W2KJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R5ANcDUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VstWoIIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SldZqPrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3VcjXukR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PcSrR7Hn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gXAcRKIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6yQLPDAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KlUssi3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WzHNOxzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tn1PZ25i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bmWstabf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r7cIXq3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VTft3uPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RvJJw1LI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ziihNxK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jPnH4l9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EiV9lg3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_226du8Ch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ruRfOw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FWgD83bB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IDDBIHsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y15eNjFJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0V5PrLgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2USogkS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_91ebJBFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vf92eV10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHfTI1Fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4qsMMFTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_22y2FRUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1zfdPhVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ubxpmDwn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yPBFV2Fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gaGtwe6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Q6TE8uw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dm9DtSfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9UBELxr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W6uWK2zY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D3NxgKOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PLAfwSnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A8uuBsZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ieCcOFmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uARtUaT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OLx3kNXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mJFnRhxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2mNZ0nxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aApBwHDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T9Awn1Bp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oEsZEfqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QLpSCWBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PMkssAfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bpsCankd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sS4Xh5ho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LVjTP1Xd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1SEMRxvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cVfNuERY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgyCHixk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KHglm1Uu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OSs6i70O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2NQ8xVet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WZpbsAw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tmBt5Po3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nOL7Xluz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lKzq329w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yqEkeKiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6O6dp5Xb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ftdb0RjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_A2ohWZ0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_R8kUnBgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r69qNSKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8VGHM4p9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jVAzj0SZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QOPzZGlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hnYsXViD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vcB70Exs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ViS4jhXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q6dV9cm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CohrmiXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rrMrG7O0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T592GZd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m8yjXKgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aGripRp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTZmIw45_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fWezOkbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AhxljaMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U9p5wPxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R8n3ZGhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LlaAz7y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BvEjLebf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_b9XpyKAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IekPtUA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gEHannYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HdNLvkAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NW5fHSl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UavX0Tyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bKdKlcqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yC4CmBnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oi8JTR3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1vGYo5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vfPYq33i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DYlSc1T3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LSJFbug7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4iIaoQBL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LyRmHDKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ufyEHOzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_si0aHDPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lRHTN51U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aFSziAPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wB7neP72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FrYpiaWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PlUiVQKT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IwCcQGzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJTNdujH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NXPMCzUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJ60ezzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JqEdeEMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_c8p9UKmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zvZRg3PA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s5teUebF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g0hc2w1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9PBGmoEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4TYT4D2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NLrTSwQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_15QxJc3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V0LHSHc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l4UPS8Bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ddrZMRhO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ktI1fqAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sqHPCxwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EsVanUsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A0Bat9ns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Y76fmvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cSKoANxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6of7cRkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qtdmdF1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BqfvPdSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dbfuQBeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aCFAiIiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JrJcsAc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GFVbzgzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GKsZRFdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nUSrSjxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WR1KdNnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ADTspsPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UzOpZp4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PYmSC2qx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B4dxAhLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G2jvDWDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ou28euIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kas2Ex7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3LLPknWq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EeLAI06S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DK6MdDlJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bRzTtzfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_14TG9GyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mYgZV734_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qvW3qjRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5HLSjDwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4V6LWYmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ug1SmWcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CV5flNFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D1mrP7Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lqqXcPpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tuxMbH57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XXJ3vuwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_38EN5kCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UnlAv5JS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iBaX7ViF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E8wgaAvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d1XH2UFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BuAdIyT9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gNuoSywV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Ir7eJ4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FK9wu5zy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uzc6axir_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_JwDfFy8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YhnQrmry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SZoDzbAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wTo26nXZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_B0vcd2MO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VwVbBMWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YQQgXb7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dQsXmefD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GKW02xFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MEs9xf93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NeRCglUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_g00jcyuO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1N3p19tx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m1UnpWO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qXKVGXQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FoJCnpOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0LdbBtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QRlWjTkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OxJnWOb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7vWmSirY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wkTra54p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EfbjcvdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YqLZ9QRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W7xJ9Ctx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rq59algo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DYtQ51T0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Z1US60I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0qkWAeQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_z3fRczjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aeoSnNmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7f4TOu53_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLXOFFXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sGJGb8p2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0maB2agr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kW1YgarG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aLlhF1Qj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AQ9PCsJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qJrrB4LW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PX3eMuwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z0nDUIkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Pk3jyxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XErVpA2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iMG7fAZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BvEu3ZBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XGBRVYsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rRSOUZZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vQCu5CBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ObgPNCbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SaCHoWz2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BjaZFHeu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zUjba2fj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IP8yZQ63_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V4OzuPOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8le94ju2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1cYpSpyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0qtEnYUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f8c9qrno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_slE8UqbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s99tNnL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8BcDuYox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eHftDpNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ydmaof5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1IOmmZtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ROEAJt82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bkYBdZEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZybftAE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rWPoFFnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ivFkZw60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WBcH7nsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oIzRpB7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HybbqWF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dUMeBOLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6sgbtYU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3C60PPkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LDu2TyZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YdkzkihB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuIaQpy6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dozqEulc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_S9Qo3geA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_shtJvFFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZU0i7tzQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PH6twuhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2sCoIf7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WYyqjpC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DGDa5JL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_s0aGIPsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2E62FXzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AlariGGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_feKWr8k8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e2CJ5gsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z9cglXor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b3BlgaN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Aadcmwtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UIvkpH9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_owBVP0Vq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c11iYTLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8B13OzBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zm0anDFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WKROOJgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2aCJaR6F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rJiW6Bps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AP9Ijhsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qoecsUAU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_whOkLGgJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_evmYxazF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r3hdSXRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDdmncPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3RJ9LjHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bljRZtFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gsCoPmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8X8DEz9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Fv0B9FY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1R925xvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ehgYzvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aTCC0gsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f5v7kZ6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zfoWfL1V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TVoCFE6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VftVcRoA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ac3Nogo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rcE5tcIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t5nt0uNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zlR8fbWR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSkIOE68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_of2h5HiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X4Hctvdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aPAFGxAA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fXl7vfwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NYgEFeNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nou4umIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WiJn41xO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V5bPEvHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k6PZ7Hua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FPJVo1Lr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tevNVp3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ULGMfio9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4sen8wGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWUNzPBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mMvdLrwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXywrOfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LcOfQKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hxBNBeqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_00ZyrHj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZQiksze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vhoq11eK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L7RSfnuu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G7AUgTmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kLHQBHWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NJ2eEISV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_72HxO3Xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2TF53SBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lMThRRbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbVFg57b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cZeqpwWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WyZH0733_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GMNFyjde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V4yH53EW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EuWVARpx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nC2dD0kg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_AVbE30Yq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_obQrdWZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_42c9cweJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8muZD0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EPMTtbuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EOT3cUh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6EbhqWqa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPWOwiHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgLq156q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LnNik41b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z3pDL0Ie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTp5Fzxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dL71MEGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9vYTWuXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JkOtUucy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kxAkyTEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1mBmRGsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TOjypnT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I8EqUDiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vIxy9Hzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ea9Y5Sx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O8sVq8Im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nJm2PA8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SvqUb0hW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tAE8KhUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5b9waU4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PdWQ7NqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gilZvp7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lUoQ24f9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qYKnD6Eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qE5GRhkf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l0720qaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gk7QvMBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WfCppQ5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AX7eyayM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b1GaGwaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FG5QxWcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N11UZv6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OUAzbREn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UVdaFxub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pt5pVko6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GmB8fLgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fgd2BdRv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_80zi1VwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6dAHPYUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p9QRRxzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xTPMiyBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X69FBi5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7OfyamF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BKwmNUH5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0h7fivxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jxj3pOz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5cgj7ULQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CY41nv1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gql8XlWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o5ne1wRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EIbDBWOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gaG0Eogj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MUREXdRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xnAFkbnC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HPPZCYfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_isuMAlck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LjNefozf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZoOGLYGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5ty12FXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vGZ3gW3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0iSmPqVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_b6BYIqAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hZmz24a6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z3LwBioP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r7kUyEM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p407cnpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_V6JscZGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0Yr1Wf5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TTL0W12J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bZ4n1RP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wj3GIVsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZNUaRyiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RmbBFQRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CGL2HNlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xZvpSb6j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DAUnssA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_f1f5IAzu;
  SignalLine sLine_XkhrdZot;
  SignalLine sLine_GPzbIbGL;
  SignalLine sLine_43utngpc;
  SignalLine sLine_H43OeFRz;
  SignalBiquad sBiquad_s_4s7be17T;
  SignalLine sLine_YNuWWzQf;
  SignalLine sLine_aEqbcvph;
  SignalLine sLine_pAoz0qzv;
  SignalLine sLine_StpcYWIT;
  SignalBiquad sBiquad_s_m66Eb3tl;
  SignalLine sLine_OuM4mXhJ;
  SignalLine sLine_TiFb1Mln;
  SignalLine sLine_JCseSIzw;
  SignalLine sLine_abCyhpHG;
  SignalLine sLine_zV0MnwxW;
  SignalBiquad sBiquad_s_xofGdaPo;
  SignalLine sLine_Et6IlaAO;
  SignalLine sLine_oVvG2NTE;
  SignalLine sLine_BluLhYtD;
  SignalLine sLine_qNyBC0OG;
  SignalLine sLine_n4PItvHP;
  SignalBiquad sBiquad_s_4SPeoXsZ;
  SignalLine sLine_BmCcsSSx;
  SignalLine sLine_pupWQY5Q;
  SignalLine sLine_xXv76yoX;
  SignalLine sLine_HgLkaKVz;
  SignalBiquad sBiquad_s_NE3LjwBb;
  SignalLine sLine_57zFFsEf;
  SignalLine sLine_oOOsYjOi;
  SignalLine sLine_zncnk3RK;
  SignalLine sLine_sbkdpxZ6;
  SignalLine sLine_5h3WQMC3;
  SignalBiquad sBiquad_s_1XklfG9m;
  ControlVar cVar_3TiZzHM0;
  ControlVar cVar_FD8GzGHx;
  ControlVar cVar_Larw0SDH;
  ControlVar cVar_1si5qZuH;
  ControlSlice cSlice_VB2N1fgI;
  ControlVar cVar_ZrZ4YvCR;
  ControlVar cVar_gpcflSWF;
  ControlIf cIf_sKaBNSSy;
  ControlIf cIf_ocDCcOpx;
  ControlBinop cBinop_WAh8i4qQ;
  ControlBinop cBinop_U787T57n;
  ControlBinop cBinop_RGODLzfu;
  ControlBinop cBinop_uK4ciWiN;
  ControlBinop cBinop_IYYSFFls;
  ControlIf cIf_IL1NHUql;
  ControlBinop cBinop_W1AJi1ID;
  ControlBinop cBinop_3pnXB16m;
  ControlBinop cBinop_XIZU4S53;
  ControlBinop cBinop_XWgwE5s1;
  ControlBinop cBinop_Kl6trUHQ;
  ControlVar cVar_KiN4EdHx;
  ControlIf cIf_dGdtYXTG;
  ControlIf cIf_hVjaE1z2;
  ControlBinop cBinop_Fo9cdJs8;
  ControlBinop cBinop_dBzl12x5;
  ControlBinop cBinop_eFF19Ti3;
  ControlBinop cBinop_tNArEbZZ;
  ControlBinop cBinop_fDjmgB3H;
  ControlIf cIf_x62ZKVHK;
  ControlBinop cBinop_EDVEVILI;
  ControlBinop cBinop_U9BmChhy;
  ControlBinop cBinop_z8JYCIih;
  ControlBinop cBinop_I8IUJGNW;
  ControlBinop cBinop_IJ81zupT;
  ControlVar cVar_xibhVU8b;
  ControlIf cIf_E9p83bLt;
  ControlIf cIf_836vqsP7;
  ControlBinop cBinop_4Zw77Zx3;
  ControlBinop cBinop_tjttSMWo;
  ControlBinop cBinop_MGDROdCm;
  ControlBinop cBinop_xqy8qL0L;
  ControlBinop cBinop_a9HahfVe;
  ControlIf cIf_QPxVymb1;
  ControlBinop cBinop_EVkK5DVQ;
  ControlBinop cBinop_KH29FlrZ;
  ControlBinop cBinop_eXKOqvHn;
  ControlBinop cBinop_zXFN1Dov;
  ControlBinop cBinop_EpD5aIGZ;
  ControlIf cIf_tFrdn9DP;
  ControlSlice cSlice_z7N1AGaQ;
  ControlVar cVar_0moLF1M2;
  ControlSlice cSlice_Bwtn4W9e;
  ControlVar cVar_VAWwjABe;
  ControlSlice cSlice_kuJImnuZ;
  ControlVar cVar_pGFfO1lx;
  ControlSlice cSlice_cpZ0MmAO;
  ControlVar cVar_iYdc6OUu;
  ControlBinop cBinop_NeInS1gR;
  ControlBinop cBinop_upm6VWIV;
  ControlBinop cBinop_k3Rn2Afg;
  ControlBinop cBinop_XPRsmybZ;
  ControlBinop cBinop_eUyOKBfW;
  ControlBinop cBinop_DigWbyy0;
  ControlBinop cBinop_haaChyZm;
  ControlBinop cBinop_mf7XtWCJ;
  ControlVar cVar_i0yAd5le;
  ControlBinop cBinop_wrH1SnFJ;
  ControlBinop cBinop_Nl3jFsHy;
  ControlBinop cBinop_8BAZq5da;
  ControlBinop cBinop_oQXlVE6e;
  ControlBinop cBinop_L8zm3rf8;
  ControlBinop cBinop_Ycznjj1g;
  ControlBinop cBinop_lEwhKV8N;
  ControlBinop cBinop_u3apqJEp;
  ControlVar cVar_RZdSo10Z;
  ControlVar cVar_JrYZca8g;
  ControlBinop cBinop_dyzWY5vJ;
  ControlBinop cBinop_7jH9SnPy;
  ControlBinop cBinop_spbvtqb3;
  ControlBinop cBinop_bao0O3ic;
  ControlBinop cBinop_RyPGxDG9;
  ControlBinop cBinop_4MrrfGDB;
  ControlBinop cBinop_13dOS1kD;
  ControlBinop cBinop_TKlXixmD;
  ControlBinop cBinop_bis8MbW6;
  ControlBinop cBinop_kc76uUj1;
  ControlBinop cBinop_630kkyGu;
  ControlBinop cBinop_fRjx2BHB;
  ControlBinop cBinop_R5ANcDUa;
  ControlBinop cBinop_VstWoIIQ;
  ControlBinop cBinop_SldZqPrG;
  ControlBinop cBinop_3VcjXukR;
  ControlBinop cBinop_PcSrR7Hn;
  ControlBinop cBinop_gXAcRKIW;
  ControlBinop cBinop_6yQLPDAg;
  ControlBinop cBinop_WzHNOxzV;
  ControlVar cVar_tn1PZ25i;
  ControlVar cVar_bmWstabf;
  ControlVar cVar_r7cIXq3Q;
  ControlBinop cBinop_6ruRfOw0;
  ControlBinop cBinop_FWgD83bB;
  ControlBinop cBinop_IDDBIHsZ;
  ControlBinop cBinop_0V5PrLgG;
  ControlBinop cBinop_2USogkS4;
  ControlBinop cBinop_91ebJBFl;
  ControlBinop cBinop_Vf92eV10;
  ControlBinop cBinop_RHfTI1Fd;
  ControlBinop cBinop_2mNZ0nxs;
  ControlBinop cBinop_T9Awn1Bp;
  ControlBinop cBinop_oEsZEfqW;
  ControlBinop cBinop_bpsCankd;
  ControlBinop cBinop_sS4Xh5ho;
  ControlBinop cBinop_LVjTP1Xd;
  ControlBinop cBinop_1SEMRxvp;
  ControlBinop cBinop_cVfNuERY;
  ControlBinop cBinop_KHglm1Uu;
  ControlBinop cBinop_2NQ8xVet;
  ControlBinop cBinop_WZpbsAw6;
  ControlBinop cBinop_nOL7Xluz;
  ControlBinop cBinop_lKzq329w;
  ControlBinop cBinop_yqEkeKiT;
  ControlBinop cBinop_Ftdb0RjY;
  ControlVar cVar_A2ohWZ0m;
  ControlVar cVar_R8kUnBgI;
  ControlVar cVar_r69qNSKY;
  ControlBinop cBinop_q6dV9cm8;
  ControlBinop cBinop_CohrmiXi;
  ControlBinop cBinop_rrMrG7O0;
  ControlBinop cBinop_m8yjXKgT;
  ControlBinop cBinop_aGripRp3;
  ControlBinop cBinop_xTZmIw45;
  ControlBinop cBinop_fWezOkbn;
  ControlBinop cBinop_AhxljaMa;
  ControlBinop cBinop_U9p5wPxl;
  ControlBinop cBinop_yC4CmBnz;
  ControlBinop cBinop_G1vGYo5C;
  ControlBinop cBinop_vfPYq33i;
  SignalVarf sVarf_eIh4RhVp;
  SignalVarf sVarf_NWttL9Lh;
  SignalVarf sVarf_dY5XSvv2;
  ControlSlice cSlice_LSJFbug7;
  ControlVar cVar_4iIaoQBL;
  ControlVar cVar_ufyEHOzo;
  ControlIf cIf_si0aHDPI;
  ControlIf cIf_lRHTN51U;
  ControlBinop cBinop_wB7neP72;
  ControlBinop cBinop_FrYpiaWN;
  ControlBinop cBinop_bJTNdujH;
  ControlBinop cBinop_NXPMCzUp;
  ControlBinop cBinop_JqEdeEMJ;
  ControlIf cIf_c8p9UKmt;
  ControlBinop cBinop_zvZRg3PA;
  ControlBinop cBinop_s5teUebF;
  ControlBinop cBinop_9PBGmoEn;
  ControlBinop cBinop_4TYT4D2e;
  ControlBinop cBinop_NLrTSwQS;
  ControlVar cVar_ktI1fqAv;
  ControlIf cIf_sqHPCxwD;
  ControlIf cIf_EsVanUsC;
  ControlBinop cBinop_0Y76fmvZ;
  ControlBinop cBinop_cSKoANxC;
  ControlBinop cBinop_BqfvPdSt;
  ControlBinop cBinop_dbfuQBeB;
  ControlBinop cBinop_JrJcsAc2;
  ControlIf cIf_GFVbzgzY;
  ControlBinop cBinop_GKsZRFdo;
  ControlBinop cBinop_nUSrSjxx;
  ControlBinop cBinop_ADTspsPS;
  ControlBinop cBinop_UzOpZp4G;
  ControlBinop cBinop_PYmSC2qx;
  ControlVar cVar_3LLPknWq;
  ControlIf cIf_EeLAI06S;
  ControlIf cIf_DK6MdDlJ;
  ControlBinop cBinop_14TG9GyK;
  ControlBinop cBinop_mYgZV734;
  ControlBinop cBinop_4V6LWYmJ;
  ControlBinop cBinop_Ug1SmWcX;
  ControlBinop cBinop_D1mrP7Yw;
  ControlIf cIf_lqqXcPpB;
  ControlBinop cBinop_tuxMbH57;
  ControlBinop cBinop_XXJ3vuwB;
  ControlBinop cBinop_UnlAv5JS;
  ControlBinop cBinop_iBaX7ViF;
  ControlBinop cBinop_E8wgaAvn;
  ControlIf cIf_FK9wu5zy;
  ControlSlice cSlice_JwDfFy8q;
  ControlVar cVar_YhnQrmry;
  ControlSlice cSlice_B0vcd2MO;
  ControlVar cVar_VwVbBMWB;
  ControlSlice cSlice_GKW02xFh;
  ControlVar cVar_MEs9xf93;
  ControlSlice cSlice_1N3p19tx;
  ControlVar cVar_m1UnpWO7;
  ControlBinop cBinop_rq59algo;
  ControlBinop cBinop_1Z1US60I;
  ControlBinop cBinop_0qkWAeQI;
  ControlBinop cBinop_7f4TOu53;
  ControlBinop cBinop_XLXOFFXX;
  ControlBinop cBinop_sGJGb8p2;
  ControlBinop cBinop_0maB2agr;
  ControlBinop cBinop_kW1YgarG;
  ControlVar cVar_aLlhF1Qj;
  ControlBinop cBinop_AQ9PCsJp;
  ControlBinop cBinop_qJrrB4LW;
  ControlBinop cBinop_PX3eMuwK;
  ControlBinop cBinop_Z0nDUIkQ;
  ControlBinop cBinop_2Pk3jyxz;
  ControlBinop cBinop_XErVpA2x;
  ControlBinop cBinop_iMG7fAZN;
  ControlBinop cBinop_XGBRVYsN;
  ControlVar cVar_rRSOUZZO;
  ControlVar cVar_vQCu5CBd;
  ControlBinop cBinop_8le94ju2;
  ControlBinop cBinop_1cYpSpyd;
  ControlBinop cBinop_0qtEnYUE;
  ControlBinop cBinop_slE8UqbH;
  ControlBinop cBinop_s99tNnL9;
  ControlBinop cBinop_8BcDuYox;
  ControlBinop cBinop_eHftDpNR;
  ControlBinop cBinop_ydmaof5G;
  ControlBinop cBinop_1IOmmZtL;
  ControlBinop cBinop_PH6twuhS;
  ControlBinop cBinop_WYyqjpC4;
  ControlBinop cBinop_DGDa5JL3;
  ControlBinop cBinop_AlariGGg;
  ControlBinop cBinop_feKWr8k8;
  ControlBinop cBinop_e2CJ5gsu;
  ControlBinop cBinop_z9cglXor;
  ControlBinop cBinop_b3BlgaN9;
  ControlBinop cBinop_Aadcmwtw;
  ControlBinop cBinop_UIvkpH9D;
  ControlBinop cBinop_c11iYTLR;
  ControlVar cVar_8B13OzBQ;
  ControlVar cVar_Zm0anDFO;
  ControlVar cVar_WKROOJgX;
  ControlBinop cBinop_r3hdSXRi;
  ControlBinop cBinop_dDdmncPh;
  ControlBinop cBinop_3RJ9LjHZ;
  ControlBinop cBinop_6gsCoPmr;
  ControlBinop cBinop_8X8DEz9O;
  ControlBinop cBinop_2Fv0B9FY;
  ControlBinop cBinop_1R925xvl;
  ControlBinop cBinop_7ehgYzvr;
  ControlBinop cBinop_V5bPEvHW;
  ControlBinop cBinop_FPJVo1Lr;
  ControlBinop cBinop_tevNVp3D;
  ControlBinop cBinop_sWUNzPBV;
  ControlBinop cBinop_mMvdLrwB;
  ControlBinop cBinop_rXywrOfG;
  ControlBinop cBinop_1LcOfQKA;
  ControlBinop cBinop_hxBNBeqq;
  ControlBinop cBinop_xZQiksze;
  ControlBinop cBinop_L7RSfnuu;
  ControlBinop cBinop_G7AUgTmI;
  ControlBinop cBinop_NJ2eEISV;
  ControlBinop cBinop_72HxO3Xi;
  ControlBinop cBinop_2TF53SBG;
  ControlBinop cBinop_gbVFg57b;
  ControlVar cVar_cZeqpwWp;
  ControlVar cVar_WyZH0733;
  ControlVar cVar_GMNFyjde;
  ControlBinop cBinop_L8muZD0j;
  ControlBinop cBinop_EPMTtbuO;
  ControlBinop cBinop_EOT3cUh1;
  ControlBinop cBinop_pPWOwiHi;
  ControlBinop cBinop_HgLq156q;
  ControlBinop cBinop_LnNik41b;
  ControlBinop cBinop_z3pDL0Ie;
  ControlBinop cBinop_xTp5Fzxb;
  ControlBinop cBinop_dL71MEGT;
  ControlBinop cBinop_SvqUb0hW;
  ControlBinop cBinop_5b9waU4o;
  ControlBinop cBinop_PdWQ7NqN;
  SignalVarf sVarf_K11cRdFV;
  SignalVarf sVarf_nSHEZeYE;
  SignalVarf sVarf_YjlcM5id;
  ControlVar cVar_gilZvp7E;
  ControlVar cVar_lUoQ24f9;
  ControlBinop cBinop_AX7eyayM;
  ControlBinop cBinop_b1GaGwaa;
  ControlBinop cBinop_FG5QxWcZ;
  ControlBinop cBinop_OUAzbREn;
  ControlBinop cBinop_UVdaFxub;
  ControlBinop cBinop_Pt5pVko6;
  ControlBinop cBinop_GmB8fLgO;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
