/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_f1f5IAzu);
  numBytes += sLine_init(&sLine_XkhrdZot);
  numBytes += sLine_init(&sLine_GPzbIbGL);
  numBytes += sLine_init(&sLine_43utngpc);
  numBytes += sLine_init(&sLine_H43OeFRz);
  numBytes += sBiquad_init(&sBiquad_s_4s7be17T);
  numBytes += sLine_init(&sLine_YNuWWzQf);
  numBytes += sLine_init(&sLine_aEqbcvph);
  numBytes += sLine_init(&sLine_pAoz0qzv);
  numBytes += sLine_init(&sLine_StpcYWIT);
  numBytes += sBiquad_init(&sBiquad_s_m66Eb3tl);
  numBytes += sLine_init(&sLine_OuM4mXhJ);
  numBytes += sLine_init(&sLine_TiFb1Mln);
  numBytes += sLine_init(&sLine_JCseSIzw);
  numBytes += sLine_init(&sLine_abCyhpHG);
  numBytes += sLine_init(&sLine_zV0MnwxW);
  numBytes += sBiquad_init(&sBiquad_s_xofGdaPo);
  numBytes += sLine_init(&sLine_Et6IlaAO);
  numBytes += sLine_init(&sLine_oVvG2NTE);
  numBytes += sLine_init(&sLine_BluLhYtD);
  numBytes += sLine_init(&sLine_qNyBC0OG);
  numBytes += sLine_init(&sLine_n4PItvHP);
  numBytes += sBiquad_init(&sBiquad_s_4SPeoXsZ);
  numBytes += sLine_init(&sLine_BmCcsSSx);
  numBytes += sLine_init(&sLine_pupWQY5Q);
  numBytes += sLine_init(&sLine_xXv76yoX);
  numBytes += sLine_init(&sLine_HgLkaKVz);
  numBytes += sBiquad_init(&sBiquad_s_NE3LjwBb);
  numBytes += sLine_init(&sLine_57zFFsEf);
  numBytes += sLine_init(&sLine_oOOsYjOi);
  numBytes += sLine_init(&sLine_zncnk3RK);
  numBytes += sLine_init(&sLine_sbkdpxZ6);
  numBytes += sLine_init(&sLine_5h3WQMC3);
  numBytes += sBiquad_init(&sBiquad_s_1XklfG9m);
  numBytes += cVar_init_f(&cVar_3TiZzHM0, 0.0f);
  numBytes += cVar_init_f(&cVar_FD8GzGHx, 0.0f);
  numBytes += cVar_init_f(&cVar_Larw0SDH, 0.0f);
  numBytes += cVar_init_f(&cVar_1si5qZuH, 0.0f);
  numBytes += cSlice_init(&cSlice_VB2N1fgI, 1, -1);
  numBytes += cVar_init_f(&cVar_ZrZ4YvCR, 1337.0f);
  numBytes += cVar_init_f(&cVar_gpcflSWF, 0.0f);
  numBytes += cIf_init(&cIf_sKaBNSSy, false);
  numBytes += cIf_init(&cIf_ocDCcOpx, false);
  numBytes += cBinop_init(&cBinop_WAh8i4qQ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_IL1NHUql, false);
  numBytes += cBinop_init(&cBinop_XIZU4S53, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XWgwE5s1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Kl6trUHQ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_KiN4EdHx, 0.0f);
  numBytes += cIf_init(&cIf_dGdtYXTG, false);
  numBytes += cIf_init(&cIf_hVjaE1z2, false);
  numBytes += cBinop_init(&cBinop_Fo9cdJs8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_x62ZKVHK, false);
  numBytes += cBinop_init(&cBinop_z8JYCIih, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_I8IUJGNW, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IJ81zupT, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_xibhVU8b, 0.0f);
  numBytes += cIf_init(&cIf_E9p83bLt, false);
  numBytes += cIf_init(&cIf_836vqsP7, false);
  numBytes += cBinop_init(&cBinop_4Zw77Zx3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QPxVymb1, false);
  numBytes += cBinop_init(&cBinop_eXKOqvHn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zXFN1Dov, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EpD5aIGZ, -15.0f); // __eq
  numBytes += cIf_init(&cIf_tFrdn9DP, false);
  numBytes += cSlice_init(&cSlice_z7N1AGaQ, 1, -1);
  numBytes += cVar_init_f(&cVar_0moLF1M2, 0.0f);
  numBytes += cSlice_init(&cSlice_Bwtn4W9e, 1, -1);
  numBytes += cVar_init_f(&cVar_VAWwjABe, 0.0f);
  numBytes += cSlice_init(&cSlice_kuJImnuZ, 1, -1);
  numBytes += cVar_init_f(&cVar_pGFfO1lx, 0.0f);
  numBytes += cSlice_init(&cSlice_cpZ0MmAO, 1, -1);
  numBytes += cVar_init_f(&cVar_iYdc6OUu, 0.313f);
  numBytes += cBinop_init(&cBinop_upm6VWIV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_k3Rn2Afg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_i0yAd5le, 0.0f);
  numBytes += cVar_init_f(&cVar_RZdSo10Z, 1337.0f);
  numBytes += cVar_init_f(&cVar_JrYZca8g, 0.3f);
  numBytes += cBinop_init(&cBinop_7jH9SnPy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RyPGxDG9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4MrrfGDB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_13dOS1kD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TKlXixmD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bis8MbW6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_630kkyGu, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fRjx2BHB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_tn1PZ25i, 0.0f);
  numBytes += cVar_init_f(&cVar_bmWstabf, 1337.0f);
  numBytes += cVar_init_f(&cVar_r7cIXq3Q, 0.313f);
  numBytes += cBinop_init(&cBinop_FWgD83bB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2USogkS4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_91ebJBFl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Vf92eV10, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RHfTI1Fd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_T9Awn1Bp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_oEsZEfqW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_A2ohWZ0m, 0.0f);
  numBytes += cVar_init_f(&cVar_R8kUnBgI, 1037.0f);
  numBytes += cVar_init_f(&cVar_r69qNSKY, 0.4f);
  numBytes += cBinop_init(&cBinop_CohrmiXi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aGripRp3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xTZmIw45, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fWezOkbn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AhxljaMa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U9p5wPxl, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eIh4RhVp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NWttL9Lh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dY5XSvv2, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_LSJFbug7, 1, -1);
  numBytes += cVar_init_f(&cVar_4iIaoQBL, 1337.0f);
  numBytes += cVar_init_f(&cVar_ufyEHOzo, 0.0f);
  numBytes += cIf_init(&cIf_si0aHDPI, false);
  numBytes += cIf_init(&cIf_lRHTN51U, false);
  numBytes += cBinop_init(&cBinop_wB7neP72, 0.0f); // __pow
  numBytes += cIf_init(&cIf_c8p9UKmt, false);
  numBytes += cBinop_init(&cBinop_9PBGmoEn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4TYT4D2e, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NLrTSwQS, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ktI1fqAv, 0.0f);
  numBytes += cIf_init(&cIf_sqHPCxwD, false);
  numBytes += cIf_init(&cIf_EsVanUsC, false);
  numBytes += cBinop_init(&cBinop_0Y76fmvZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_GFVbzgzY, false);
  numBytes += cBinop_init(&cBinop_ADTspsPS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UzOpZp4G, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PYmSC2qx, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_3LLPknWq, 0.0f);
  numBytes += cIf_init(&cIf_EeLAI06S, false);
  numBytes += cIf_init(&cIf_DK6MdDlJ, false);
  numBytes += cBinop_init(&cBinop_14TG9GyK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lqqXcPpB, false);
  numBytes += cBinop_init(&cBinop_UnlAv5JS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_iBaX7ViF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_E8wgaAvn, -15.0f); // __eq
  numBytes += cIf_init(&cIf_FK9wu5zy, false);
  numBytes += cSlice_init(&cSlice_JwDfFy8q, 1, -1);
  numBytes += cVar_init_f(&cVar_YhnQrmry, 0.0f);
  numBytes += cSlice_init(&cSlice_B0vcd2MO, 1, -1);
  numBytes += cVar_init_f(&cVar_VwVbBMWB, 0.0f);
  numBytes += cSlice_init(&cSlice_GKW02xFh, 1, -1);
  numBytes += cVar_init_f(&cVar_MEs9xf93, 0.0f);
  numBytes += cSlice_init(&cSlice_1N3p19tx, 1, -1);
  numBytes += cVar_init_f(&cVar_m1UnpWO7, 0.313f);
  numBytes += cBinop_init(&cBinop_1Z1US60I, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_0qkWAeQI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aLlhF1Qj, 0.0f);
  numBytes += cVar_init_f(&cVar_rRSOUZZO, 1337.0f);
  numBytes += cVar_init_f(&cVar_vQCu5CBd, 0.3f);
  numBytes += cBinop_init(&cBinop_1cYpSpyd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s99tNnL9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8BcDuYox, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eHftDpNR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ydmaof5G, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1IOmmZtL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WYyqjpC4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DGDa5JL3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_8B13OzBQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Zm0anDFO, 1337.0f);
  numBytes += cVar_init_f(&cVar_WKROOJgX, 0.313f);
  numBytes += cBinop_init(&cBinop_dDdmncPh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8X8DEz9O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Fv0B9FY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1R925xvl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7ehgYzvr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FPJVo1Lr, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tevNVp3D, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cZeqpwWp, 0.0f);
  numBytes += cVar_init_f(&cVar_WyZH0733, 1037.0f);
  numBytes += cVar_init_f(&cVar_GMNFyjde, 0.4f);
  numBytes += cBinop_init(&cBinop_EPMTtbuO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HgLq156q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LnNik41b, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z3pDL0Ie, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xTp5Fzxb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dL71MEGT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_K11cRdFV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nSHEZeYE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YjlcM5id, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gilZvp7E, 5705.6f);
  numBytes += cVar_init_f(&cVar_lUoQ24f9, 313.3f);
  numBytes += cBinop_init(&cBinop_AX7eyayM, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_b1GaGwaa, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_FG5QxWcZ, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BKwmNUH5_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jxj3pOz9_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0h7fivxC_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DAUnssA0_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gql8XlWv_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o5ne1wRl_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5cgj7ULQ_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CY41nv1I_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EIbDBWOC_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HPPZCYfJ_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xnAFkbnC_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MUREXdRy_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZoOGLYGP_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LjNefozf_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_isuMAlck_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0iSmPqVg_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vGZ3gW3z_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5ty12FXi_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z3LwBioP_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r7kUyEM2_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b6BYIqAe_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hZmz24a6_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p407cnpE_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TTL0W12J_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0Yr1Wf5f_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V6JscZGo_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZNUaRyiI_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wj3GIVsD_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bZ4n1RP5_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xZvpSb6j_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CGL2HNlg_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RmbBFQRp_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gaG0Eogj_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_3TiZzHM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fgd2BdRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_FD8GzGHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80zi1VwG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Larw0SDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6dAHPYUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_1si5qZuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p9QRRxzj_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WfCppQ5l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gk7QvMBE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l0720qaa_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_2yF6KU3v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VB2N1fgI, 0, m, &cSlice_VB2N1fgI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v7BQadcb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_VB2N1fgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m0qyHBJd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m0qyHBJd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ZrZ4YvCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m0qyHBJd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_m0qyHBJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5cgj7ULQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_gpcflSWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W1AJi1ID_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sKaBNSSy, 0, m, &cIf_sKaBNSSy_sendMessage);
}

void Heavy_WSTD_3Q::cIf_sKaBNSSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3pnXB16m_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_ocDCcOpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9ByZfS3d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uK4ciWiN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Va9BaCcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WAh8i4qQ, HV_BINOP_POW, 0, m, &cBinop_WAh8i4qQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WAh8i4qQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IL1NHUql, 0, m, &cIf_IL1NHUql_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U787T57n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IYYSFFls_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MyjKXwBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RGODLzfu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WsbCKsx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ocDCcOpx, 0, m, &cIf_ocDCcOpx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RGODLzfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ocDCcOpx, 1, m, &cIf_ocDCcOpx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uK4ciWiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_U787T57n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9ByZfS3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IL1NHUql, 0, m, &cIf_IL1NHUql_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IYYSFFls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WAh8i4qQ, HV_BINOP_POW, 1, m, &cBinop_WAh8i4qQ_sendMessage);
  cMsg_Va9BaCcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_IL1NHUql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_eIh4RhVp, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_W1AJi1ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKaBNSSy, 1, m, &cIf_sKaBNSSy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3pnXB16m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWgwE5s1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XWgwE5s1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kl6trUHQ, HV_BINOP_EQ, 1, m, &cBinop_Kl6trUHQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_O0HjWUmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIZU4S53, HV_BINOP_ADD, 0, m, &cBinop_XIZU4S53_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XIZU4S53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MyjKXwBR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WsbCKsx3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XWgwE5s1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IL1NHUql, 1, m, &cIf_IL1NHUql_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Kl6trUHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0FrrwFKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_0FrrwFKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eIh4RhVp, m);
}

void Heavy_WSTD_3Q::cCast_VdpSkHSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gpcflSWF, 0, m, &cVar_gpcflSWF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0rVvUMgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0HjWUmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_NIzLCxpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XIZU4S53, HV_BINOP_ADD, 1, m, &cBinop_XIZU4S53_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWgwE5s1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XWgwE5s1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kl6trUHQ, HV_BINOP_EQ, 0, m, &cBinop_Kl6trUHQ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_KiN4EdHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EDVEVILI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dGdtYXTG, 0, m, &cIf_dGdtYXTG_sendMessage);
}

void Heavy_WSTD_3Q::cIf_dGdtYXTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_U9BmChhy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_hVjaE1z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_K8ABnSsh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tNArEbZZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_C4hTBQmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fo9cdJs8, HV_BINOP_POW, 0, m, &cBinop_Fo9cdJs8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Fo9cdJs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x62ZKVHK, 0, m, &cIf_x62ZKVHK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dBzl12x5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fDjmgB3H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4XAe1Q2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eFF19Ti3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NyYTnXvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hVjaE1z2, 0, m, &cIf_hVjaE1z2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eFF19Ti3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hVjaE1z2, 1, m, &cIf_hVjaE1z2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tNArEbZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dBzl12x5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_K8ABnSsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_x62ZKVHK, 0, m, &cIf_x62ZKVHK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fDjmgB3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fo9cdJs8, HV_BINOP_POW, 1, m, &cBinop_Fo9cdJs8_sendMessage);
  cMsg_C4hTBQmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_x62ZKVHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yC4CmBnz_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_G1vGYo5C_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_vfPYq33i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_EDVEVILI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dGdtYXTG, 1, m, &cIf_dGdtYXTG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U9BmChhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I8IUJGNW, HV_BINOP_GREATER_THAN, 1, m, &cBinop_I8IUJGNW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IJ81zupT, HV_BINOP_EQ, 1, m, &cBinop_IJ81zupT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_VEVqIo1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z8JYCIih, HV_BINOP_ADD, 0, m, &cBinop_z8JYCIih_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z8JYCIih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4XAe1Q2u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NyYTnXvb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I8IUJGNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x62ZKVHK, 1, m, &cIf_x62ZKVHK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IJ81zupT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JDFLfUJ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JDFLfUJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yC4CmBnz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_G1vGYo5C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_vfPYq33i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qSvTPXZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KiN4EdHx, 0, m, &cVar_KiN4EdHx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pmD1cni8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VEVqIo1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Ndz1yVB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z8JYCIih, HV_BINOP_ADD, 1, m, &cBinop_z8JYCIih_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I8IUJGNW, HV_BINOP_GREATER_THAN, 0, m, &cBinop_I8IUJGNW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IJ81zupT, HV_BINOP_EQ, 0, m, &cBinop_IJ81zupT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_xibhVU8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_EVkK5DVQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_E9p83bLt, 0, m, &cIf_E9p83bLt_sendMessage);
}

void Heavy_WSTD_3Q::cIf_E9p83bLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KH29FlrZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_836vqsP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cLviec0V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xqy8qL0L_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_n2KIRWUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zw77Zx3, HV_BINOP_POW, 0, m, &cBinop_4Zw77Zx3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Zw77Zx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QPxVymb1, 0, m, &cIf_QPxVymb1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tjttSMWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_a9HahfVe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XPKLKzHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MGDROdCm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VkhoHB7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_836vqsP7, 0, m, &cIf_836vqsP7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MGDROdCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_836vqsP7, 1, m, &cIf_836vqsP7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xqy8qL0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_tjttSMWo_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cLviec0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QPxVymb1, 0, m, &cIf_QPxVymb1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a9HahfVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Zw77Zx3, HV_BINOP_POW, 1, m, &cBinop_4Zw77Zx3_sendMessage);
  cMsg_n2KIRWUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_QPxVymb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dY5XSvv2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_EVkK5DVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E9p83bLt, 1, m, &cIf_E9p83bLt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KH29FlrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXFN1Dov, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zXFN1Dov_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpD5aIGZ, HV_BINOP_EQ, 1, m, &cBinop_EpD5aIGZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qqOBcCc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eXKOqvHn, HV_BINOP_ADD, 0, m, &cBinop_eXKOqvHn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eXKOqvHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XPKLKzHh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VkhoHB7M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zXFN1Dov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QPxVymb1, 1, m, &cIf_QPxVymb1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EpD5aIGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_drSL5ig4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_drSL5ig4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dY5XSvv2, m);
}

void Heavy_WSTD_3Q::cCast_vguvejq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eXKOqvHn, HV_BINOP_ADD, 1, m, &cBinop_eXKOqvHn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zXFN1Dov, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zXFN1Dov_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EpD5aIGZ, HV_BINOP_EQ, 0, m, &cBinop_EpD5aIGZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vdwW3gAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xibhVU8b, 0, m, &cVar_xibhVU8b_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m0vXOg8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qqOBcCc4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_tFrdn9DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_NWttL9Lh, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_MJQeHJWn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z7N1AGaQ, 0, m, &cSlice_z7N1AGaQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0Cf06qf1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_z7N1AGaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tag7pDKT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tag7pDKT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_0moLF1M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tag7pDKT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_tag7pDKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gql8XlWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_0Cf06qf1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Bwtn4W9e, 0, m, &cSlice_Bwtn4W9e_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2yF6KU3v_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Bwtn4W9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KSYT4KVs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KSYT4KVs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_VAWwjABe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KSYT4KVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_KSYT4KVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EIbDBWOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_v7BQadcb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kuJImnuZ, 0, m, &cSlice_kuJImnuZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1ZPxNCbo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_kuJImnuZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jgS4mhbL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jgS4mhbL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_pGFfO1lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jgS4mhbL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_jgS4mhbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o5ne1wRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_1ZPxNCbo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cpZ0MmAO, 0, m, &cSlice_cpZ0MmAO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_cpZ0MmAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IZcaZcyy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IZcaZcyy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_iYdc6OUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IZcaZcyy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IZcaZcyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CY41nv1I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_PZEt0PUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1f5IAzu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BtxSTJGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XkhrdZot, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BLdckITu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GPzbIbGL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_mP8ifXLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_43utngpc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VD6YWCL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H43OeFRz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_k9cpfCUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iHUN1hdh_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_iHUN1hdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upm6VWIV, HV_BINOP_DIVIDE, 1, m, &cBinop_upm6VWIV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rkhAWNi9_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_W5Nn1KjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_NeInS1gR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mAU5NmAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_W5Nn1KjO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NeInS1gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_upm6VWIV, HV_BINOP_DIVIDE, 0, m, &cBinop_upm6VWIV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rkhAWNi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mAU5NmAr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_upm6VWIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3Rn2Afg, HV_BINOP_MULTIPLY, 1, m, &cBinop_k3Rn2Afg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k3Rn2Afg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VT1DJBBs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C1zPjjCy_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2SbkFVAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hCEunPMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_gXL2CbHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zqjccqmK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XPRsmybZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eUyOKBfW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eUyOKBfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3Rn2Afg, HV_BINOP_MULTIPLY, 0, m, &cBinop_k3Rn2Afg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DigWbyy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_haaChyZm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_haaChyZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_19wJN13f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mf7XtWCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i0yAd5le, 1, m, &cVar_i0yAd5le_sendMessage);
}

void Heavy_WSTD_3Q::cVar_i0yAd5le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pfmJ8rqu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wrH1SnFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RyPGxDG9, HV_BINOP_MULTIPLY, 1, m, &cBinop_RyPGxDG9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Nl3jFsHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wrH1SnFJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8BAZq5da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_oQXlVE6e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oQXlVE6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MrrfGDB, HV_BINOP_MULTIPLY, 1, m, &cBinop_4MrrfGDB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L8zm3rf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_13dOS1kD, HV_BINOP_MULTIPLY, 1, m, &cBinop_13dOS1kD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ycznjj1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L8zm3rf8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lEwhKV8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TKlXixmD, HV_BINOP_MULTIPLY, 1, m, &cBinop_TKlXixmD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_auPJDSQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u3apqJEp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_u3apqJEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bis8MbW6, HV_BINOP_MULTIPLY, 1, m, &cBinop_bis8MbW6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_RZdSo10Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FVWq7dBT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XPRsmybZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_su7fY9Dh_sendMessage);
}

void Heavy_WSTD_3Q::cVar_JrYZca8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DigWbyy0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VT1DJBBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2SbkFVAi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_C1zPjjCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_gXL2CbHF_sendMessage);
}

void Heavy_WSTD_3Q::cSend_hCEunPMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MUREXdRy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zqjccqmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xnAFkbnC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_psT32wXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HPPZCYfJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_19wJN13f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dyzWY5vJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dyzWY5vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7jH9SnPy, HV_BINOP_MULTIPLY, 1, m, &cBinop_7jH9SnPy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7jH9SnPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_spbvtqb3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_spbvtqb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_psT32wXI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_pfmJ8rqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bao0O3ic_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bao0O3ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_87cwiaC9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BOz42yCU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_36ReGYsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n45y0UM1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjmmXSk0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GrqE8Dvw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RyPGxDG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZEt0PUr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4MrrfGDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtxSTJGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_13dOS1kD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLdckITu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TKlXixmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mP8ifXLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bis8MbW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VD6YWCL1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_9WZpSM7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JrYZca8g, 1, m, &cVar_JrYZca8g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_u6VRT7Ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RZdSo10Z, 0, m, &cVar_RZdSo10Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GrqE8Dvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RyPGxDG9, HV_BINOP_MULTIPLY, 0, m, &cBinop_RyPGxDG9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_36ReGYsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TKlXixmD, HV_BINOP_MULTIPLY, 0, m, &cBinop_TKlXixmD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FjmmXSk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4MrrfGDB, HV_BINOP_MULTIPLY, 0, m, &cBinop_4MrrfGDB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BOz42yCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bis8MbW6, HV_BINOP_MULTIPLY, 0, m, &cBinop_bis8MbW6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n45y0UM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_13dOS1kD, HV_BINOP_MULTIPLY, 0, m, &cBinop_13dOS1kD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_87cwiaC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_su7fY9Dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i0yAd5le, 0, m, &cVar_i0yAd5le_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FVWq7dBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JrYZca8g, 0, m, &cVar_JrYZca8g_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_JQ1CdOgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YNuWWzQf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hP062pCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aEqbcvph, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6HQkiYDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pAoz0qzv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jcw7wmm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_StpcYWIT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Q4ZvOoNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_22HNphaq_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_22HNphaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_630kkyGu, HV_BINOP_DIVIDE, 1, m, &cBinop_630kkyGu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IL4mkdH_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_AWzflOlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kc76uUj1_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MHcUmW88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_AWzflOlb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kc76uUj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_630kkyGu, HV_BINOP_DIVIDE, 0, m, &cBinop_630kkyGu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8IL4mkdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MHcUmW88_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_630kkyGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fRjx2BHB, HV_BINOP_MULTIPLY, 1, m, &cBinop_fRjx2BHB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fRjx2BHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RvJJw1LI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VTft3uPo_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_03yiA0eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ziihNxK6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_mh8W2KJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jPnH4l9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_R5ANcDUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_VstWoIIQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VstWoIIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fRjx2BHB, HV_BINOP_MULTIPLY, 0, m, &cBinop_fRjx2BHB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SldZqPrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_3VcjXukR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3VcjXukR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_226du8Ch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PcSrR7Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91ebJBFl, HV_BINOP_MULTIPLY, 1, m, &cBinop_91ebJBFl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gXAcRKIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tn1PZ25i, 1, m, &cVar_tn1PZ25i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6yQLPDAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vf92eV10, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vf92eV10_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KlUssi3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WzHNOxzV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WzHNOxzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHfTI1Fd, HV_BINOP_MULTIPLY, 1, m, &cBinop_RHfTI1Fd_sendMessage);
}

void Heavy_WSTD_3Q::cVar_tn1PZ25i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y15eNjFJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_bmWstabf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1zfdPhVo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_R5ANcDUa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ubxpmDwn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_r7cIXq3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SldZqPrG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VTft3uPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_mh8W2KJr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RvJJw1LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_03yiA0eC_sendMessage);
}

void Heavy_WSTD_3Q::cSend_ziihNxK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_isuMAlck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_jPnH4l9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LjNefozf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_EiV9lg3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZoOGLYGP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_226du8Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6ruRfOw0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6ruRfOw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FWgD83bB, HV_BINOP_MULTIPLY, 1, m, &cBinop_FWgD83bB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FWgD83bB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IDDBIHsZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IDDBIHsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EiV9lg3M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Y15eNjFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0V5PrLgG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0V5PrLgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dm9DtSfr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gaGtwe6K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yPBFV2Fn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Q6TE8uw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2USogkS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JQ1CdOgC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_91ebJBFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hP062pCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Vf92eV10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6HQkiYDE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RHfTI1Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcw7wmm0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_4qsMMFTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r7cIXq3Q, 1, m, &cVar_r7cIXq3Q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_22y2FRUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bmWstabf, 0, m, &cVar_bmWstabf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1zfdPhVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r7cIXq3Q, 0, m, &cVar_r7cIXq3Q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ubxpmDwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tn1PZ25i, 0, m, &cVar_tn1PZ25i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yPBFV2Fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_91ebJBFl, HV_BINOP_MULTIPLY, 0, m, &cBinop_91ebJBFl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gaGtwe6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vf92eV10, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vf92eV10_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2Q6TE8uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2USogkS4, HV_BINOP_MULTIPLY, 0, m, &cBinop_2USogkS4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Dm9DtSfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RHfTI1Fd, HV_BINOP_MULTIPLY, 0, m, &cBinop_RHfTI1Fd_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9UBELxr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OuM4mXhJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_W6uWK2zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TiFb1Mln, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_D3NxgKOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JCseSIzw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_PLAfwSnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_abCyhpHG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_A8uuBsZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zV0MnwxW, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ieCcOFmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uARtUaT7_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_uARtUaT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T9Awn1Bp, HV_BINOP_DIVIDE, 1, m, &cBinop_T9Awn1Bp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aApBwHDR_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OLx3kNXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2mNZ0nxs_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_mJFnRhxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OLx3kNXx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2mNZ0nxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T9Awn1Bp, HV_BINOP_DIVIDE, 0, m, &cBinop_T9Awn1Bp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aApBwHDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mJFnRhxw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_T9Awn1Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oEsZEfqW, HV_BINOP_MULTIPLY, 1, m, &cBinop_oEsZEfqW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oEsZEfqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8VGHM4p9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jVAzj0SZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_QLpSCWBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QOPzZGlh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_PMkssAfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hnYsXViD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bpsCankd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sS4Xh5ho_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sS4Xh5ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oEsZEfqW, HV_BINOP_MULTIPLY, 0, m, &cBinop_oEsZEfqW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LVjTP1Xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1SEMRxvp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1SEMRxvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ViS4jhXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cVfNuERY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aGripRp3, HV_BINOP_MULTIPLY, 1, m, &cBinop_aGripRp3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tgyCHixk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KHglm1Uu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KHglm1Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cVfNuERY_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OSs6i70O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2NQ8xVet_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2NQ8xVet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTZmIw45, HV_BINOP_MULTIPLY, 1, m, &cBinop_xTZmIw45_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WZpbsAw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fWezOkbn, HV_BINOP_MULTIPLY, 1, m, &cBinop_fWezOkbn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tmBt5Po3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nOL7Xluz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nOL7Xluz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WZpbsAw6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lKzq329w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A2ohWZ0m, 1, m, &cVar_A2ohWZ0m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yqEkeKiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhxljaMa, HV_BINOP_MULTIPLY, 1, m, &cBinop_AhxljaMa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6O6dp5Xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ftdb0RjY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ftdb0RjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U9p5wPxl, HV_BINOP_MULTIPLY, 1, m, &cBinop_U9p5wPxl_sendMessage);
}

void Heavy_WSTD_3Q::cVar_A2ohWZ0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T592GZd0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_R8kUnBgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKdKlcqd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_bpsCankd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UavX0Tyr_sendMessage);
}

void Heavy_WSTD_3Q::cVar_r69qNSKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LVjTP1Xd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8VGHM4p9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_QLpSCWBr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jVAzj0SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_PMkssAfR_sendMessage);
}

void Heavy_WSTD_3Q::cSend_QOPzZGlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5ty12FXi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hnYsXViD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vGZ3gW3z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vcB70Exs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0iSmPqVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ViS4jhXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_q6dV9cm8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_q6dV9cm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CohrmiXi, HV_BINOP_MULTIPLY, 1, m, &cBinop_CohrmiXi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CohrmiXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rrMrG7O0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rrMrG7O0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vcB70Exs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_T592GZd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_m8yjXKgT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m8yjXKgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HdNLvkAn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IekPtUA0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BvEjLebf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gEHannYy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b9XpyKAn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NW5fHSl9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aGripRp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9UBELxr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xTZmIw45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W6uWK2zY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fWezOkbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D3NxgKOT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_AhxljaMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PLAfwSnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_U9p5wPxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A8uuBsZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_R8n3ZGhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R8kUnBgI, 0, m, &cVar_R8kUnBgI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LlaAz7y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r69qNSKY, 1, m, &cVar_r69qNSKY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BvEjLebf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AhxljaMa, HV_BINOP_MULTIPLY, 0, m, &cBinop_AhxljaMa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_b9XpyKAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTZmIw45, HV_BINOP_MULTIPLY, 0, m, &cBinop_xTZmIw45_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IekPtUA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U9p5wPxl, HV_BINOP_MULTIPLY, 0, m, &cBinop_U9p5wPxl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gEHannYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fWezOkbn, HV_BINOP_MULTIPLY, 0, m, &cBinop_fWezOkbn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HdNLvkAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_NW5fHSl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aGripRp3, HV_BINOP_MULTIPLY, 0, m, &cBinop_aGripRp3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UavX0Tyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A2ohWZ0m, 0, m, &cVar_A2ohWZ0m_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bKdKlcqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r69qNSKY, 0, m, &cVar_r69qNSKY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yC4CmBnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tFrdn9DP, 1, m, &cIf_tFrdn9DP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Oi8JTR3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NWttL9Lh, m);
}

void Heavy_WSTD_3Q::cBinop_G1vGYo5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oi8JTR3P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vfPYq33i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tFrdn9DP, 0, m, &cIf_tFrdn9DP_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_DYlSc1T3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LSJFbug7, 0, m, &cSlice_LSJFbug7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dQsXmefD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_LSJFbug7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LyRmHDKH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LyRmHDKH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_4iIaoQBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LyRmHDKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_LyRmHDKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b6BYIqAe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ufyEHOzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zvZRg3PA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_si0aHDPI, 0, m, &cIf_si0aHDPI_sendMessage);
}

void Heavy_WSTD_3Q::cIf_si0aHDPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_s5teUebF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_lRHTN51U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EJ60ezzX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NXPMCzUp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_aFSziAPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wB7neP72, HV_BINOP_POW, 0, m, &cBinop_wB7neP72_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wB7neP72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c8p9UKmt, 0, m, &cIf_c8p9UKmt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FrYpiaWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JqEdeEMJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PlUiVQKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lRHTN51U, 0, m, &cIf_lRHTN51U_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IwCcQGzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bJTNdujH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bJTNdujH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lRHTN51U, 1, m, &cIf_lRHTN51U_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NXPMCzUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FrYpiaWN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_EJ60ezzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_c8p9UKmt, 0, m, &cIf_c8p9UKmt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JqEdeEMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wB7neP72, HV_BINOP_POW, 1, m, &cBinop_wB7neP72_sendMessage);
  cMsg_aFSziAPg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_c8p9UKmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_K11cRdFV, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_zvZRg3PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_si0aHDPI, 1, m, &cIf_si0aHDPI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s5teUebF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TYT4D2e, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4TYT4D2e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NLrTSwQS, HV_BINOP_EQ, 1, m, &cBinop_NLrTSwQS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_g0hc2w1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9PBGmoEn, HV_BINOP_ADD, 0, m, &cBinop_9PBGmoEn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9PBGmoEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IwCcQGzF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PlUiVQKT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4TYT4D2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c8p9UKmt, 1, m, &cIf_c8p9UKmt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NLrTSwQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_15QxJc3A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_15QxJc3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_K11cRdFV, m);
}

void Heavy_WSTD_3Q::cCast_V0LHSHc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ufyEHOzo, 0, m, &cVar_ufyEHOzo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l4UPS8Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0hc2w1k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ddrZMRhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9PBGmoEn, HV_BINOP_ADD, 1, m, &cBinop_9PBGmoEn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TYT4D2e, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4TYT4D2e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NLrTSwQS, HV_BINOP_EQ, 0, m, &cBinop_NLrTSwQS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ktI1fqAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GKsZRFdo_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sqHPCxwD, 0, m, &cIf_sqHPCxwD_sendMessage);
}

void Heavy_WSTD_3Q::cIf_sqHPCxwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nUSrSjxx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_EsVanUsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_aCFAiIiI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dbfuQBeB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_A0Bat9ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Y76fmvZ, HV_BINOP_POW, 0, m, &cBinop_0Y76fmvZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0Y76fmvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GFVbzgzY, 0, m, &cIf_GFVbzgzY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cSKoANxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JrJcsAc2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6of7cRkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EsVanUsC, 0, m, &cIf_EsVanUsC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qtdmdF1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BqfvPdSt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BqfvPdSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EsVanUsC, 1, m, &cIf_EsVanUsC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dbfuQBeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_cSKoANxC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_aCFAiIiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_GFVbzgzY, 0, m, &cIf_GFVbzgzY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JrJcsAc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Y76fmvZ, HV_BINOP_POW, 1, m, &cBinop_0Y76fmvZ_sendMessage);
  cMsg_A0Bat9ns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_GFVbzgzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SvqUb0hW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5b9waU4o_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PdWQ7NqN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_GKsZRFdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sqHPCxwD, 1, m, &cIf_sqHPCxwD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nUSrSjxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzOpZp4G, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UzOpZp4G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PYmSC2qx, HV_BINOP_EQ, 1, m, &cBinop_PYmSC2qx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WR1KdNnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADTspsPS, HV_BINOP_ADD, 0, m, &cBinop_ADTspsPS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ADTspsPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qtdmdF1B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6of7cRkB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UzOpZp4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GFVbzgzY, 1, m, &cIf_GFVbzgzY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PYmSC2qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B4dxAhLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_B4dxAhLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SvqUb0hW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5b9waU4o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PdWQ7NqN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_G2jvDWDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ADTspsPS, HV_BINOP_ADD, 1, m, &cBinop_ADTspsPS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UzOpZp4G, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UzOpZp4G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PYmSC2qx, HV_BINOP_EQ, 0, m, &cBinop_PYmSC2qx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ou28euIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ktI1fqAv, 0, m, &cVar_ktI1fqAv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kas2Ex7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WR1KdNnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_3LLPknWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tuxMbH57_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_EeLAI06S, 0, m, &cIf_EeLAI06S_sendMessage);
}

void Heavy_WSTD_3Q::cIf_EeLAI06S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XXJ3vuwB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_DK6MdDlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CV5flNFg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Ug1SmWcX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_bRzTtzfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_14TG9GyK, HV_BINOP_POW, 0, m, &cBinop_14TG9GyK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_14TG9GyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lqqXcPpB, 0, m, &cIf_lqqXcPpB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mYgZV734_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_D1mrP7Yw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qvW3qjRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DK6MdDlJ, 0, m, &cIf_DK6MdDlJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5HLSjDwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4V6LWYmJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4V6LWYmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DK6MdDlJ, 1, m, &cIf_DK6MdDlJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ug1SmWcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mYgZV734_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CV5flNFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lqqXcPpB, 0, m, &cIf_lqqXcPpB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_D1mrP7Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_14TG9GyK, HV_BINOP_POW, 1, m, &cBinop_14TG9GyK_sendMessage);
  cMsg_bRzTtzfa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_lqqXcPpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YjlcM5id, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_tuxMbH57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EeLAI06S, 1, m, &cIf_EeLAI06S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XXJ3vuwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBaX7ViF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_iBaX7ViF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8wgaAvn, HV_BINOP_EQ, 1, m, &cBinop_E8wgaAvn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_38EN5kCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UnlAv5JS, HV_BINOP_ADD, 0, m, &cBinop_UnlAv5JS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UnlAv5JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5HLSjDwy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qvW3qjRV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iBaX7ViF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lqqXcPpB, 1, m, &cIf_lqqXcPpB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E8wgaAvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1XH2UFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_d1XH2UFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YjlcM5id, m);
}

void Heavy_WSTD_3Q::cCast_BuAdIyT9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_38EN5kCY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_gNuoSywV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UnlAv5JS, HV_BINOP_ADD, 1, m, &cBinop_UnlAv5JS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBaX7ViF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_iBaX7ViF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8wgaAvn, HV_BINOP_EQ, 0, m, &cBinop_E8wgaAvn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0Ir7eJ4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3LLPknWq, 0, m, &cVar_3LLPknWq_sendMessage);
}

void Heavy_WSTD_3Q::cIf_FK9wu5zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nSHEZeYE, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_uzc6axir_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JwDfFy8q, 0, m, &cSlice_JwDfFy8q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wTo26nXZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_JwDfFy8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SZoDzbAm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SZoDzbAm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_YhnQrmry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SZoDzbAm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_SZoDzbAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z3LwBioP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_wTo26nXZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B0vcd2MO, 0, m, &cSlice_B0vcd2MO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DYlSc1T3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_B0vcd2MO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YQQgXb7b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YQQgXb7b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_VwVbBMWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YQQgXb7b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YQQgXb7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p407cnpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_dQsXmefD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GKW02xFh, 0, m, &cSlice_GKW02xFh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g00jcyuO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_GKW02xFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NeRCglUG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NeRCglUG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_MEs9xf93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NeRCglUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_NeRCglUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r7kUyEM2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_g00jcyuO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1N3p19tx, 0, m, &cSlice_1N3p19tx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_1N3p19tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qXKVGXQa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qXKVGXQa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_m1UnpWO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qXKVGXQa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_qXKVGXQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hZmz24a6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_FoJCnpOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Et6IlaAO, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_O0LdbBtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oVvG2NTE, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QRlWjTkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BluLhYtD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OxJnWOb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qNyBC0OG, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7vWmSirY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n4PItvHP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wkTra54p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EfbjcvdN_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_EfbjcvdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Z1US60I, HV_BINOP_DIVIDE, 1, m, &cBinop_1Z1US60I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DYtQ51T0_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_YqLZ9QRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rq59algo_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_W7xJ9Ctx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_YqLZ9QRS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rq59algo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Z1US60I, HV_BINOP_DIVIDE, 0, m, &cBinop_1Z1US60I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DYtQ51T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W7xJ9Ctx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1Z1US60I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0qkWAeQI, HV_BINOP_MULTIPLY, 1, m, &cBinop_0qkWAeQI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0qkWAeQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ObgPNCbf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaCHoWz2_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_z3fRczjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BjaZFHeu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_aeoSnNmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zUjba2fj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7f4TOu53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XLXOFFXX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XLXOFFXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0qkWAeQI, HV_BINOP_MULTIPLY, 0, m, &cBinop_0qkWAeQI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sGJGb8p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0maB2agr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0maB2agr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V4OzuPOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kW1YgarG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aLlhF1Qj, 1, m, &cVar_aLlhF1Qj_sendMessage);
}

void Heavy_WSTD_3Q::cVar_aLlhF1Qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f8c9qrno_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_AQ9PCsJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s99tNnL9, HV_BINOP_MULTIPLY, 1, m, &cBinop_s99tNnL9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qJrrB4LW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AQ9PCsJp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PX3eMuwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Z0nDUIkQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z0nDUIkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8BcDuYox, HV_BINOP_MULTIPLY, 1, m, &cBinop_8BcDuYox_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2Pk3jyxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHftDpNR, HV_BINOP_MULTIPLY, 1, m, &cBinop_eHftDpNR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XErVpA2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2Pk3jyxz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iMG7fAZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ydmaof5G, HV_BINOP_MULTIPLY, 1, m, &cBinop_ydmaof5G_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BvEu3ZBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XGBRVYsN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XGBRVYsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1IOmmZtL, HV_BINOP_MULTIPLY, 1, m, &cBinop_1IOmmZtL_sendMessage);
}

void Heavy_WSTD_3Q::cVar_rRSOUZZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dUMeBOLn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_7f4TOu53_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R6sgbtYU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vQCu5CBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sGJGb8p2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ObgPNCbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_z3fRczjU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SaCHoWz2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_aeoSnNmA_sendMessage);
}

void Heavy_WSTD_3Q::cSend_BjaZFHeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V6JscZGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zUjba2fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0Yr1Wf5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IP8yZQ63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TTL0W12J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_V4OzuPOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8le94ju2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8le94ju2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1cYpSpyd, HV_BINOP_MULTIPLY, 1, m, &cBinop_1cYpSpyd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1cYpSpyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0qtEnYUE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0qtEnYUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IP8yZQ63_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_f8c9qrno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_slE8UqbH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_slE8UqbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WBcH7nsQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rWPoFFnJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HybbqWF5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ivFkZw60_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZybftAE7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oIzRpB7m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s99tNnL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FoJCnpOu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8BcDuYox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0LdbBtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eHftDpNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QRlWjTkC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ydmaof5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OxJnWOb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1IOmmZtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7vWmSirY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_ROEAJt82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rRSOUZZO, 0, m, &cVar_rRSOUZZO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bkYBdZEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vQCu5CBd, 1, m, &cVar_vQCu5CBd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZybftAE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8BcDuYox, HV_BINOP_MULTIPLY, 0, m, &cBinop_8BcDuYox_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rWPoFFnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1IOmmZtL, HV_BINOP_MULTIPLY, 0, m, &cBinop_1IOmmZtL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ivFkZw60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eHftDpNR, HV_BINOP_MULTIPLY, 0, m, &cBinop_eHftDpNR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WBcH7nsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_oIzRpB7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s99tNnL9, HV_BINOP_MULTIPLY, 0, m, &cBinop_s99tNnL9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HybbqWF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ydmaof5G, HV_BINOP_MULTIPLY, 0, m, &cBinop_ydmaof5G_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dUMeBOLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vQCu5CBd, 0, m, &cVar_vQCu5CBd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_R6sgbtYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aLlhF1Qj, 0, m, &cVar_aLlhF1Qj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3C60PPkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BmCcsSSx, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LDu2TyZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pupWQY5Q, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YdkzkihB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xXv76yoX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MuIaQpy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HgLkaKVz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dozqEulc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_S9Qo3geA_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_S9Qo3geA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYyqjpC4, HV_BINOP_DIVIDE, 1, m, &cBinop_WYyqjpC4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2sCoIf7m_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_shtJvFFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_PH6twuhS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZU0i7tzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_shtJvFFe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PH6twuhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYyqjpC4, HV_BINOP_DIVIDE, 0, m, &cBinop_WYyqjpC4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2sCoIf7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZU0i7tzQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WYyqjpC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGDa5JL3, HV_BINOP_MULTIPLY, 1, m, &cBinop_DGDa5JL3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DGDa5JL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rJiW6Bps_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2aCJaR6F_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_s0aGIPsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AP9Ijhsa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_2E62FXzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qoecsUAU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_AlariGGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_feKWr8k8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_feKWr8k8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGDa5JL3, HV_BINOP_MULTIPLY, 0, m, &cBinop_DGDa5JL3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e2CJ5gsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_z9cglXor_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z9cglXor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_evmYxazF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_b3BlgaN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Fv0B9FY, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Fv0B9FY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Aadcmwtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8B13OzBQ, 1, m, &cVar_8B13OzBQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UIvkpH9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1R925xvl, HV_BINOP_MULTIPLY, 1, m, &cBinop_1R925xvl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_owBVP0Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c11iYTLR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c11iYTLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ehgYzvr, HV_BINOP_MULTIPLY, 1, m, &cBinop_7ehgYzvr_sendMessage);
}

void Heavy_WSTD_3Q::cVar_8B13OzBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bljRZtFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Zm0anDFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zfoWfL1V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_AlariGGg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TVoCFE6u_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WKROOJgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_e2CJ5gsu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2aCJaR6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_2E62FXzW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rJiW6Bps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_s0aGIPsz_sendMessage);
}

void Heavy_WSTD_3Q::cSend_AP9Ijhsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bZ4n1RP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_qoecsUAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wj3GIVsD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_whOkLGgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZNUaRyiI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_evmYxazF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_r3hdSXRi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r3hdSXRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDdmncPh, HV_BINOP_MULTIPLY, 1, m, &cBinop_dDdmncPh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dDdmncPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3RJ9LjHZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3RJ9LjHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_whOkLGgJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_bljRZtFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6gsCoPmr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6gsCoPmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t5nt0uNh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ac3Nogo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VftVcRoA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rcE5tcIm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8X8DEz9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3C60PPkJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2Fv0B9FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LDu2TyZb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1R925xvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YdkzkihB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7ehgYzvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MuIaQpy6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_aTCC0gsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WKROOJgX, 1, m, &cVar_WKROOJgX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f5v7kZ6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zm0anDFO, 0, m, &cVar_Zm0anDFO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zfoWfL1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WKROOJgX, 0, m, &cVar_WKROOJgX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TVoCFE6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8B13OzBQ, 0, m, &cVar_8B13OzBQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VftVcRoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Fv0B9FY, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Fv0B9FY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ac3Nogo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1R925xvl, HV_BINOP_MULTIPLY, 0, m, &cBinop_1R925xvl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rcE5tcIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8X8DEz9O, HV_BINOP_MULTIPLY, 0, m, &cBinop_8X8DEz9O_sendMessage);
}

void Heavy_WSTD_3Q::cCast_t5nt0uNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ehgYzvr, HV_BINOP_MULTIPLY, 0, m, &cBinop_7ehgYzvr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zlR8fbWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_57zFFsEf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MSkIOE68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oOOsYjOi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_of2h5HiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zncnk3RK, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_X4Hctvdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sbkdpxZ6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aPAFGxAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5h3WQMC3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fXl7vfwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NYgEFeNp_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_NYgEFeNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FPJVo1Lr, HV_BINOP_DIVIDE, 1, m, &cBinop_FPJVo1Lr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k6PZ7Hua_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_nou4umIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_V5bPEvHW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WiJn41xO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nou4umIm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V5bPEvHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FPJVo1Lr, HV_BINOP_DIVIDE, 0, m, &cBinop_FPJVo1Lr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_k6PZ7Hua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WiJn41xO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FPJVo1Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tevNVp3D, HV_BINOP_MULTIPLY, 1, m, &cBinop_tevNVp3D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tevNVp3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EuWVARpx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V4yH53EW_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ULGMfio9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nC2dD0kg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_4sen8wGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AVbE30Yq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sWUNzPBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mMvdLrwB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mMvdLrwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tevNVp3D, HV_BINOP_MULTIPLY, 0, m, &cBinop_tevNVp3D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rXywrOfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1LcOfQKA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1LcOfQKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_42c9cweJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hxBNBeqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgLq156q, HV_BINOP_MULTIPLY, 1, m, &cBinop_HgLq156q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_00ZyrHj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xZQiksze_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xZQiksze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hxBNBeqq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Vhoq11eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_L7RSfnuu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L7RSfnuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LnNik41b, HV_BINOP_MULTIPLY, 1, m, &cBinop_LnNik41b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G7AUgTmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3pDL0Ie, HV_BINOP_MULTIPLY, 1, m, &cBinop_z3pDL0Ie_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kLHQBHWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NJ2eEISV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NJ2eEISV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_G7AUgTmI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_72HxO3Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cZeqpwWp, 1, m, &cVar_cZeqpwWp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2TF53SBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTp5Fzxb, HV_BINOP_MULTIPLY, 1, m, &cBinop_xTp5Fzxb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lMThRRbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gbVFg57b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gbVFg57b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dL71MEGT, HV_BINOP_MULTIPLY, 1, m, &cBinop_dL71MEGT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_cZeqpwWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6EbhqWqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_WyZH0733_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nJm2PA8X_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sWUNzPBV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O8sVq8Im_sendMessage);
}

void Heavy_WSTD_3Q::cVar_GMNFyjde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rXywrOfG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V4yH53EW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4sen8wGI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EuWVARpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ULGMfio9_sendMessage);
}

void Heavy_WSTD_3Q::cSend_nC2dD0kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RmbBFQRp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_AVbE30Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CGL2HNlg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_obQrdWZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xZvpSb6j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_42c9cweJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L8muZD0j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L8muZD0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPMTtbuO, HV_BINOP_MULTIPLY, 1, m, &cBinop_EPMTtbuO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EPMTtbuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EOT3cUh1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EOT3cUh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_obQrdWZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_6EbhqWqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pPWOwiHi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pPWOwiHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I8EqUDiA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1mBmRGsW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ea9Y5Sx8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TOjypnT2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kxAkyTEa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vIxy9Hzj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HgLq156q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zlR8fbWR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LnNik41b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MSkIOE68_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_z3pDL0Ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_of2h5HiS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xTp5Fzxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X4Hctvdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dL71MEGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aPAFGxAA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_9vYTWuXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WyZH0733, 0, m, &cVar_WyZH0733_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JkOtUucy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GMNFyjde, 1, m, &cVar_GMNFyjde_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kxAkyTEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LnNik41b, HV_BINOP_MULTIPLY, 0, m, &cBinop_LnNik41b_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1mBmRGsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dL71MEGT, HV_BINOP_MULTIPLY, 0, m, &cBinop_dL71MEGT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TOjypnT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3pDL0Ie, HV_BINOP_MULTIPLY, 0, m, &cBinop_z3pDL0Ie_sendMessage);
}

void Heavy_WSTD_3Q::cCast_I8EqUDiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_vIxy9Hzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HgLq156q, HV_BINOP_MULTIPLY, 0, m, &cBinop_HgLq156q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ea9Y5Sx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xTp5Fzxb, HV_BINOP_MULTIPLY, 0, m, &cBinop_xTp5Fzxb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_O8sVq8Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cZeqpwWp, 0, m, &cVar_cZeqpwWp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nJm2PA8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GMNFyjde, 0, m, &cVar_GMNFyjde_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SvqUb0hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FK9wu5zy, 1, m, &cIf_FK9wu5zy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tAE8KhUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nSHEZeYE, m);
}

void Heavy_WSTD_3Q::cBinop_5b9waU4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tAE8KhUb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PdWQ7NqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FK9wu5zy, 0, m, &cIf_FK9wu5zy_sendMessage);
}

void Heavy_WSTD_3Q::cVar_gilZvp7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b1GaGwaa, HV_BINOP_DIVIDE, 0, m, &cBinop_b1GaGwaa_sendMessage);
}

void Heavy_WSTD_3Q::cVar_lUoQ24f9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AX7eyayM, HV_BINOP_DIVIDE, 1, m, &cBinop_AX7eyayM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b1GaGwaa, HV_BINOP_DIVIDE, 1, m, &cBinop_b1GaGwaa_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qYKnD6Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG5QxWcZ, HV_BINOP_DIVIDE, 0, m, &cBinop_FG5QxWcZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qE5GRhkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG5QxWcZ, HV_BINOP_DIVIDE, 1, m, &cBinop_FG5QxWcZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l0720qaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AX7eyayM, HV_BINOP_DIVIDE, 0, m, &cBinop_AX7eyayM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gk7QvMBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gilZvp7E, 0, m, &cVar_gilZvp7E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WfCppQ5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lUoQ24f9, 0, m, &cVar_lUoQ24f9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AX7eyayM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_qYKnD6Eg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b1GaGwaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_qE5GRhkf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FG5QxWcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_UVdaFxub_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_N11UZv6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_GmB8fLgO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OUAzbREn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_Pt5pVko6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UVdaFxub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OUAzbREn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Pt5pVko6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_N11UZv6G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GmB8fLgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xTPMiyBU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fgd2BdRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MJQeHJWn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uzc6axir_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_80zi1VwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MJQeHJWn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uzc6axir_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6dAHPYUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MJQeHJWn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uzc6axir_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_p9QRRxzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MJQeHJWn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uzc6axir_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xTPMiyBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_MJQeHJWn_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_uzc6axir_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_X69FBi5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1si5qZuH, 0, m, &cVar_1si5qZuH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7OfyamF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_3TiZzHM0, 0, m, &cVar_3TiZzHM0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FD8GzGHx, 0, m, &cVar_FD8GzGHx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Larw0SDH, 0, m, &cVar_Larw0SDH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_BKwmNUH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3TiZzHM0, 0, m, &cVar_3TiZzHM0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_0h7fivxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FD8GzGHx, 0, m, &cVar_FD8GzGHx_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jxj3pOz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Larw0SDH, 0, m, &cVar_Larw0SDH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5cgj7ULQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bmWstabf, 0, m, &cVar_bmWstabf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CY41nv1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4qsMMFTk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_22y2FRUw_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Gql8XlWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VdpSkHSL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NIzLCxpy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0rVvUMgQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_o5ne1wRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vdwW3gAM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vguvejq0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0vXOg8Z_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EIbDBWOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qSvTPXZF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ndz1yVB5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pmD1cni8_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_gaG0Eogj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k9cpfCUC_sendMessage(_c, 0, m);
  cMsg_Q4ZvOoNZ_sendMessage(_c, 0, m);
  cMsg_ieCcOFmf_sendMessage(_c, 0, m);
  cMsg_wkTra54p_sendMessage(_c, 0, m);
  cMsg_dozqEulc_sendMessage(_c, 0, m);
  cMsg_fXl7vfwq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RZdSo10Z, 0, m, &cVar_RZdSo10Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bmWstabf, 0, m, &cVar_bmWstabf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R8kUnBgI, 0, m, &cVar_R8kUnBgI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rRSOUZZO, 0, m, &cVar_rRSOUZZO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Zm0anDFO, 0, m, &cVar_Zm0anDFO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WyZH0733, 0, m, &cVar_WyZH0733_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZrZ4YvCR, 0, m, &cVar_ZrZ4YvCR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gpcflSWF, 0, m, &cVar_gpcflSWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KiN4EdHx, 0, m, &cVar_KiN4EdHx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xibhVU8b, 0, m, &cVar_xibhVU8b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0moLF1M2, 0, m, &cVar_0moLF1M2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VAWwjABe, 0, m, &cVar_VAWwjABe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pGFfO1lx, 0, m, &cVar_pGFfO1lx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iYdc6OUu, 0, m, &cVar_iYdc6OUu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4iIaoQBL, 0, m, &cVar_4iIaoQBL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ufyEHOzo, 0, m, &cVar_ufyEHOzo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ktI1fqAv, 0, m, &cVar_ktI1fqAv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3LLPknWq, 0, m, &cVar_3LLPknWq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YhnQrmry, 0, m, &cVar_YhnQrmry_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VwVbBMWB, 0, m, &cVar_VwVbBMWB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MEs9xf93, 0, m, &cVar_MEs9xf93_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m1UnpWO7, 0, m, &cVar_m1UnpWO7_sendMessage);
  cMsg_7OfyamF2_sendMessage(_c, 0, m);
  cMsg_X69FBi5q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_MUREXdRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7jH9SnPy, HV_BINOP_MULTIPLY, 0, m, &cBinop_7jH9SnPy_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xnAFkbnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Nl3jFsHy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8BAZq5da_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ycznjj1g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_lEwhKV8N_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HPPZCYfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mf7XtWCJ_sendMessage);
  cMsg_auPJDSQ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_isuMAlck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FWgD83bB, HV_BINOP_MULTIPLY, 0, m, &cBinop_FWgD83bB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LjNefozf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_6yQLPDAg_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZoOGLYGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2USogkS4, HV_BINOP_MULTIPLY, 1, m, &cBinop_2USogkS4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PcSrR7Hn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gXAcRKIW_sendMessage);
  cMsg_KlUssi3H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_5ty12FXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CohrmiXi, HV_BINOP_MULTIPLY, 0, m, &cBinop_CohrmiXi_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vGZ3gW3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tgyCHixk_sendMessage(_c, 0, m);
  cMsg_OSs6i70O_sendMessage(_c, 0, m);
  cMsg_tmBt5Po3_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_yqEkeKiT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_0iSmPqVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lKzq329w_sendMessage);
  cMsg_6O6dp5Xb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_b6BYIqAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zm0anDFO, 0, m, &cVar_Zm0anDFO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_hZmz24a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aTCC0gsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f5v7kZ6I_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Z3LwBioP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V0LHSHc8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ddrZMRhO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4UPS8Bm_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_r7kUyEM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Ir7eJ4s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gNuoSywV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BuAdIyT9_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_p407cnpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ou28euIq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2jvDWDj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kas2Ex7K_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_V6JscZGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1cYpSpyd, HV_BINOP_MULTIPLY, 0, m, &cBinop_1cYpSpyd_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_0Yr1Wf5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qJrrB4LW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PX3eMuwK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XErVpA2x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iMG7fAZN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TTL0W12J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kW1YgarG_sendMessage);
  cMsg_BvEu3ZBy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_bZ4n1RP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDdmncPh, HV_BINOP_MULTIPLY, 0, m, &cBinop_dDdmncPh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_wj3GIVsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_UIvkpH9D_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZNUaRyiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8X8DEz9O, HV_BINOP_MULTIPLY, 1, m, &cBinop_8X8DEz9O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_b3BlgaN9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Aadcmwtw_sendMessage);
  cMsg_owBVP0Vq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_RmbBFQRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EPMTtbuO, HV_BINOP_MULTIPLY, 0, m, &cBinop_EPMTtbuO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CGL2HNlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_00ZyrHj3_sendMessage(_c, 0, m);
  cMsg_Vhoq11eK_sendMessage(_c, 0, m);
  cMsg_kLHQBHWs_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_2TF53SBG_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xZvpSb6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_72HxO3Xi_sendMessage);
  cMsg_lMThRRbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_DAUnssA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1si5qZuH, 0, m, &cVar_1si5qZuH_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_f1f5IAzu, VOf(Bf0));
    __hv_line_f(&sLine_XkhrdZot, VOf(Bf1));
    __hv_line_f(&sLine_GPzbIbGL, VOf(Bf2));
    __hv_line_f(&sLine_43utngpc, VOf(Bf3));
    __hv_line_f(&sLine_H43OeFRz, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_4s7be17T, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_eIh4RhVp, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_YNuWWzQf, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_aEqbcvph, VOf(Bf1));
    __hv_line_f(&sLine_pAoz0qzv, VOf(Bf0));
    __hv_line_f(&sLine_StpcYWIT, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_m66Eb3tl, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_NWttL9Lh, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_OuM4mXhJ, VOf(Bf5));
    __hv_line_f(&sLine_TiFb1Mln, VOf(Bf1));
    __hv_line_f(&sLine_JCseSIzw, VOf(Bf2));
    __hv_line_f(&sLine_abCyhpHG, VOf(Bf4));
    __hv_line_f(&sLine_zV0MnwxW, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_xofGdaPo, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_dY5XSvv2, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Et6IlaAO, VOf(Bf6));
    __hv_line_f(&sLine_oVvG2NTE, VOf(Bf2));
    __hv_line_f(&sLine_BluLhYtD, VOf(Bf1));
    __hv_line_f(&sLine_qNyBC0OG, VOf(Bf5));
    __hv_line_f(&sLine_n4PItvHP, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4SPeoXsZ, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_K11cRdFV, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_BmCcsSSx, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_pupWQY5Q, VOf(Bf2));
    __hv_line_f(&sLine_xXv76yoX, VOf(Bf6));
    __hv_line_f(&sLine_HgLkaKVz, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_NE3LjwBb, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_nSHEZeYE, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_57zFFsEf, VOf(Bf8));
    __hv_line_f(&sLine_oOOsYjOi, VOf(Bf2));
    __hv_line_f(&sLine_zncnk3RK, VOf(Bf1));
    __hv_line_f(&sLine_sbkdpxZ6, VOf(Bf7));
    __hv_line_f(&sLine_5h3WQMC3, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_1XklfG9m, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_YjlcM5id, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
